"""Tests changes to common module."""
import json

from pytest_homeassistant_custom_component.common import (
    load_fixture, 
    load_json_value_fixture,
    load_json_array_fixture,
    load_json_object_fixture
)

def test_load_fixture():
    data = json.loads(load_fixture("test_data.json"))
    assert data == {"test_key": "test_value"}

def test_load_json_value_fixture():
    """Test load_json_value_fixture can load fixture file"""
    data = load_json_value_fixture("test_data.json")
    assert data == {"test_key": "test_value"}

def test_load_json_array_fixture():
    """Test load_json_array_fixture can load fixture file"""
    data = load_json_array_fixture("test_array.json")
    assert data == [{"test_key1": "test_value1"},{"test_key2": "test_value2"}]

def test_load_json_object_fixture():
    """Test load_json_object_fixture can load fixture file"""
    data = load_json_object_fixture("test_data.json")
    assert data == {"test_key": "test_value"}



"""
Tests for the Diagnostics integration.

This file is originally from homeassistant/core and modified by pytest-homeassistant-custom-component.
"""

from http import HTTPStatus
from typing import cast

from homeassistant.config_entries import ConfigEntry
from homeassistant.core import HomeAssistant
from homeassistant.helpers.device_registry import DeviceEntry
from homeassistant.setup import async_setup_component
from homeassistant.util.json import JsonObjectType

from pytest_homeassistant_custom_component.typing import ClientSessionGenerator


async def _get_diagnostics_for_config_entry(
    hass: HomeAssistant,
    hass_client: ClientSessionGenerator,
    config_entry: ConfigEntry,
) -> JsonObjectType:
    """Return the diagnostics config entry for the specified domain."""
    assert await async_setup_component(hass, "diagnostics", {})
    await hass.async_block_till_done()

    client = await hass_client()
    response = await client.get(
        f"/api/diagnostics/config_entry/{config_entry.entry_id}"
    )
    assert response.status == HTTPStatus.OK
    return cast(JsonObjectType, await response.json())


async def get_diagnostics_for_config_entry(
    hass: HomeAssistant,
    hass_client: ClientSessionGenerator,
    config_entry: ConfigEntry,
) -> JsonObjectType:
    """Return the diagnostics config entry for the specified domain."""
    data = await _get_diagnostics_for_config_entry(hass, hass_client, config_entry)
    return cast(JsonObjectType, data["data"])


async def _get_diagnostics_for_device(
    hass: HomeAssistant,
    hass_client: ClientSessionGenerator,
    config_entry: ConfigEntry,
    device: DeviceEntry,
) -> JsonObjectType:
    """Return the diagnostics for the specified device."""
    assert await async_setup_component(hass, "diagnostics", {})

    client = await hass_client()
    response = await client.get(
        f"/api/diagnostics/config_entry/{config_entry.entry_id}/device/{device.id}"
    )
    assert response.status == HTTPStatus.OK
    return cast(JsonObjectType, await response.json())


async def get_diagnostics_for_device(
    hass: HomeAssistant,
    hass_client: ClientSessionGenerator,
    config_entry: ConfigEntry,
    device: DeviceEntry,
) -> JsonObjectType:
    """Return the diagnostics for the specified device."""
    data = await _get_diagnostics_for_device(hass, hass_client, config_entry, device)
    return cast(JsonObjectType, data["data"])
